@@ -25,7 +25,6 @@
 #define DEFAULT_FONT_SIZE          36
 #define DEFAULT_NUMBER_FORMAT      0
 #define DEFAULT_PAGE_NUMBER        0
-#define DEFAULT_Y                  0
 #define DEFAULT_FULL_SCREEN        false
 #define DEFAULT_ORIENTATION        1
 #define DEFAULT_TRANSLATION_MODE   0
@@ -41,7 +40,11 @@
 
 #define MIN_TRANSLATION_FONT_SIZE  FONT_MIN_SIZE
 #define MAX_TRANSLATION_FONT_SIZE  FONT_MAX_SIZE
-#define TRANSLATION_FONT_FAMILY    "Nokia Sans" // TODO: Harmattan
+#ifdef Q_WS_MAEMO_5
+#define TRANSLATION_FONT_FAMILY    "Nokia Sans"
+#else
+#define TRANSLATION_FONT_FAMILY    "Nokia Pure Text"
+#endif
 #define DEFAULT_TRANSLATION_FONT_SIZE       DEFAULT_FONT_SIZE
 
 #define DEFAULT_SEARCH_MATCH_WHOLE_WORDS        true
@@ -174,17 +177,6 @@ bool Settings::isFontLoaded() const {
   return m_font != -1;
 }
 
-int Settings::y() const {
-  return m_settings->value("General/y", DEFAULT_Y).toInt();
-}
-
-void Settings::setY(int y) {
-  if (y != Settings::y()) {
-    m_settings->setValue("General/y", y);
-    emit yChanged();
-  }
-}
-
 void Settings::setFullScreen(bool fs) {
   if (fullScreen() != fs) {
     m_settings->setValue("General/fullScreen", fs);
@@ -310,5 +302,4 @@ void Settings::reset() {
   setTranslationFontSize(DEFAULT_TRANSLATION_FONT_SIZE);
   setCenterText(DEFAULT_CENTER_TEXT);
   setRecitationMode(DEFAULT_RECITATION_MODE);
-  setY(DEFAULT_Y);
 }
